@@ -1,4 +1,4 @@
-from django.contrib.auth import get_user_model, forms
+from django.contrib.auth import forms, get_user_model
 from django.core.exceptions import ValidationError
 from django.utils.translation import gettext_lazy as _
 
